#!/bin/bash

bold="`tput setaf 3`"
norm="`tput sgr0`"
green="`tput setf 2`" 
red="`tput setf 1`"

PKG="ee-authorized-keys"
VERS=`head -1 debian/changelog  | awk '{print $2}' | sed 's/[\(|\)]//g'`

## Available apt-cacher backends
# Ee
# debeeprod
# debeepreprod
# debeedev
# Ene
# debeneprod
# debenepreprod
# debenedev
# Lmx
# deblmxprod
# deblmxpreprod
# deblmxdev
BACKEND="debeedev"

## Available reprepro IP:
# Ee : eeapt@37.9.136.163
# Ene : debian@37.9.138.13
REPREPRO_CONNECTION=eeapt@37.9.136.163

## Available reprepro conf dir :
# ~/reprepro/debian
# ~/reprepro/debian-preprod
# ~/reprepro/debian-dev
REPREPRO_DIR="~/reprepro/debian-dev"

## Available reprepro dists :
# jessie-ee
# jessie-ene
REPRERPO_DIST="jessie-ee"

## Available dupload dists :
# Ee
# ee-debian-prod
# ee-debian-preprod
# ee-debian-dev
# Ene
# ene-debian-prod
# ene-debian-preprod
# ene-debian-dev
DUPLOAD_DIST="ee-debian-dev"

## Available apt-cacher connections :
#  aeon-hq: ssh pascal@10.67.71.2"
#  ene-preprod: ssh eeadmin@10.0.0.100"
#  ene-gw-natl-vip: ssh eeadmin@192.168.75.7"
#  lmx-preprod: ssh eeadmin@10.0.0.95"
#  lmx-SRV-DEBIAN: ssh -e none -p 2222 -v -C eeadmin@193.248.45.214 -t"
SRV_LIST=(
  "aeon-hq: ssh pascal@10.67.71.2"
  "ene-preprod: ssh eeadmin@10.0.0.100"
  "ene-gw-natl-vip: ssh eeadmin@192.168.75.6"
  "lmx-preprod: ssh eeadmin@10.0.0.95"
)

ARRAY_QTT=${#SRV_LIST[*]}
ARRAY_END=$((ARRAY_QTT-1))

function cleanup_reprepro () {

	echo -e "\n\t${green}Running $FUNCNAME: ssh ${REPREPRO_CONNECTION}\n${norm}"

	ssh ${REPREPRO_CONNECTION} <<ENDSSH

export TERM=LINUX
cd $REPREPRO_DIR
reprepro -V remove $REPRERPO_DIST ${PKG}
reprepro -V deleteunreferenced

ENDSSH

}

function create_push_package () {

	echo -e "\n\t${green}Running $FUNCNAME: rm -f ../${PKG}_${VERS}*\n${norm}"
  rm -f ../${PKG}_${VERS}*

	echo -e "\n\t${green}Running $FUNCNAME: dpkg-buildpackage\n${norm}"
  dpkg-buildpackage
	res=$?
	[ $res -ne 0 ] && echo "${red}error: $res.${norm}" && exit 0 

	cleanup_reprepro

	echo -e "\n\t${green}Running $FUNCNAME: dupload --to $DUPLOAD_DIST ../${PKG}_${VERS}_amd64.changes\n${norm}"
  dupload --to $DUPLOAD_DIST ../${PKG}_${VERS}_amd64.changes
	res=$?
	[ $res -gt 1 ] && echo "${red}error: $res.${norm}" && exit 0
}

function get_list () {

  echo

  for pos in `seq 0 ${ARRAY_END}`
  do
    if [ $(( $pos % 2)) -eq 0 ]
    then
      color=$norm
    else
      color=$bold
    fi
    echo -e "${color}[$pos] ${SRV_LIST[$pos]/:/:\\t\\t}"
  done

  echo $norm

}

function ssh_rmcache () {

  for connection in "${SRV_LIST[@]}"
  do
    echo -e "\n\t${green}Running $FUNCNAME: ${connection/*: /}\n${norm}"
    ${connection/*: /}  <<ENDSSH

export TERM=LINUX
sudo -i bash -s

/etc/init.d/apt-cacher-ng stop
/bin/rm -rf /var/cache/apt-cacher-ng/$BACKEND
/etc/init.d/apt-cacher-ng start

ENDSSH
  done
}

function do_main () {
  
 create_push_package
 ssh_rmcache 

}

function usage () {
cat << EOF

Ce srcipt permet le cleanup du cache apt sur le serveur distant

OPTIONS :
  -r  
  -l  Liste des serveurs apt-cacher-ng disponibles
	-p print what will be done

EOF

exit 0
}

function print_info () {

cat << EOF

rm -f ../${PKG}_${VERS}*

dpkg-buildpackage

ssh ${REPREPRO_CONNECTION}
cd $REPREPRO_DIR
reprepro -V remove $REPRERPO_DIST ${PKG}
reprepro -V dumpunreferenced

dupload --force --to $DUPLOAD_DIST ../${PKG}_${VERS}_amd64.changes
EOF

for connection in "${SRV_LIST[@]}"
do
	cat << EOF

${connection/*: /}

export TERM=LINUX
sudo -i bash -s

/etc/init.d/apt-cacher-ng stop
/bin/rm -rf /var/cache/apt-cacher-ng/$BACKEND
/etc/init.d/apt-cacher-ng start

EOF
done

exit 0
}

[ $# -eq 0 ] && echo -e "\nIl manque une option\n" && usage

while getopts "rhlp" OPTION
do
  case $OPTION in
    r) 
      DO_IT=1
      ;;
    l)
      echo -e "\nConnections available:"
      get_list
      DO_IT=0
      ;;
		p)
			print_info
			;;
    h)
      usage
      ;;
  esac
done

if [ $DO_IT -eq 1 ]
then
  do_main
fi

# vim:expandtab:shiftwidth=2:softtabstop=2:tabstop=2:noexpandtab:foldmethod=marker:foldlevel=0

